Index — jax_dataloader documentation

# Index

B | D | J | L | M | N | S

## B

batch_size (in module jax_dataloader.jax_dataloader.JAXDataLoader)

## D

data (in module jax_dataloader.jax_dataloader.JAXDataLoader)

## J

jax_dataloader.jax_dataloader.JAXDataLoader module

## L

labels (in module jax_dataloader.jax_dataloader.JAXDataLoader)

## M

module jax_dataloader.jax_dataloader.JAXDataLoader

## N

num_workers (in module jax_dataloader.jax_dataloader.JAXDataLoader)

## S

shuffle (in module jax_dataloader.jax_dataloader.JAXDataLoader)